#
# spec file for package amberol
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
Name:           amberol
Version:        2025.1
Release:        1.1
Summary:        A small and simple sound and music player that is well integrated with GNOME
License:        CC-BY-SA-3.0 AND CC0-1.0 AND GPL-3.0-or-later
URL:            https://gitlab.gnome.org/World/amberol
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  m4
BuildRequires:  gcc-c++
BuildRequires:  itstool
BuildRequires:  libxml2-tools
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  reuse
BuildRequires:  mpfrcx-devel
BuildRequires:  cargo-c
BuildRequires:  cargo-packaging >= 1.2.0+3
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.16
BuildRequires:  pkgconfig(gstreamer-audio-1.0) >= 1.16
BuildRequires:  pkgconfig(gstreamer-bad-audio-1.0) >= 1.16
BuildRequires:  pkgconfig(gstreamer-player-1.0) >= 1.16
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= 1.16
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.16
BuildRequires:  pkgconfig(gtk4) >= 4.6.0
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(gmp)
ExclusiveArch:  %{rust_tier1_arches}

%description
A small and simple sound and music player that is well integrated with GNOME.
Amberol aspires to be as small, unintrusive, and simple as possible. It does
not manage your music collection; it does not let you manage playlists, smart
or otherwise; it does not let you edit the metadata for your songs; it does
not show you lyrics for your songs, or the Wikipedia page for your bands.
Amberol plays music, and nothing else.

%lang_package

%prep
%autosetup -n %{name}-%{version} -a1 -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license LICENSES/{GPL-3.0-or-later,CC-BY-SA-3.0,CC0-1.0}.txt
%doc README.md CHANGES.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/io.bassi.Amberol.metainfo.xml
%{_datadir}/applications/io.bassi.Amberol.desktop
%{_datadir}/dbus-1/services/io.bassi.Amberol.service
%{_datadir}/glib-2.0/schemas/io.bassi.Amberol.gschema.xml
%{_datadir}/icons/*/*/*/*.svg

%files lang -f %{name}.lang

%changelog
* Mon Mar 31 2025 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2025.1:
  * Translation updates.
* Sun Oct 27 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2024.2:
  + Added:
  - Use folder.* filenames for cover art.
  - Use XDG_MUSIC_DIR as the initial folder when adding songs.
  + Changed:
  - Replaced unmaintained mpris-player crate with mpris-server.
  - Replaced deprecated gsteamer-player with gstreamer-play.
  - Translation updates.
  + Fixed:
  - UI and CSS cleanups and improvements.
  - Rename the appdata file.
* Sun Sep 22 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2024.1:
  + Add a marquee label for song details
  + Add more accessibility labels and descriptions
  + Adjust whitespace for DnD overlay
  + Port to the new libadwaita widgets
  + Update dependencies
  + Support higher scaling factors in the cover image
  + Update application metadata
  + Updated translations.
* Thu Sep 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.3:
  + Fixed:
  - Resize the waveform view when interpolating states
  - Fix cover art scaling
  - Fix deprecation warnings at build time
  + Changed: Updated translations.
- Changes from version 0.10.2:
  + Fixed:
  - Crash when adjusting volume while in background
  - Crash when adding folder after sending app to the background
  + Changed:
  - Use a better icon for the drop overlay
  - Updated translations.
- Update _service to use manuall services, and replace
  rust-packaging with cargo-c and cargo-packaging BuildRequires.
- Change compression of tarball in service and spec to zst from xz.
* Wed Apr 26 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.10.1:
  * Fixed background playback doesn't work.
* Tue Apr 25 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.10.0:
  + Added:
  - Allow restoring the playlist from the previous session.
  - Allow disabling background playback.
  - Add control to quickly muting/unmuting the audio.
  + Changed:
  - Use consistent labelling for adding single songs.
  - Use consistent terms for songs and playlist.
  - Improve rendering of cover art.
  - Separate the volume bar from the waveform display.
  + Fixed:
  - Reset the playlist position when searching.
  - Use HIG-compliant capitalization in the shortcuts view.
  - Narrow playlist view.
  - Do not add duplicate songs to the playlist.
  - Update next track button state depending on repeat mode.
  - Fix styling of the search bar.
  - Stop waveform pipeline when dropping the generator.
  - Change the ReplayGain menu translatable context.
  - Always draw last bar in waveform view.
  - Fix waveform overdrawing in RTL layout.
  - Fix waveform overdrawing.
  - Improve the readability of the drop overlay
- Updated translations.
* Wed Dec 21 2022 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.9.2:
  + Added:
  - Allow continuous seeking on the waveform widget.
  - Updated translations.
  + Changed:
  - Use new about window from libadwaita.
  + Fixed:
  - Recolor the folded playlist background.
  - Check for more file names for external covers.
  - Force the direction of the primary menu.
  - Remove toast for failed background portal requests.
  - Fully animate waveform between tracks.
* Tue Aug 30 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.9.1:
  + Added:
  - Add ReplayGain support.
  - Show hours to the playlist time.
  - Support external cover art files.
  - Add playing indicator in selection mode.
  + Changed:
  - Stabilise the shuffling behaviour.
  - Update the version of lofty.
  + Fixed:
  - Clarify the notification text for unavailable files.
  - Increase specificity of the cover art UUID.
  - Make the playlist side bar narrower.
  - Check for unsigned overflow.
  - Properly mark playlist remaining time for translation.
  + Removed:
  - Remove the "sound" keyword from the desktop file.
  + Updated translations.
- Enable parallel build, stop passing -j 1 to meson_build.
* Sat Aug  6 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.9.0:
  + Added:
  - Add key shortcut for toggling playlist shuffle.
  - Add fuzzy search to the playlist.
  + Changed:
  - Only list audio MIME types supported by lofty.
  - Update the version of lofty we depend on.
  + Fixed:
  - Add the directory MIME type to the list of supported typs.
  - Explicitly remove action bar background.
  - Make sure to maintain aspect ratio of cover art pixbuf.
  + Removed:
  - Remove MIME type associations for unsupported file types.
  + Updated translations.
* Sat Jun 25 2022 Dead Mozay <dead_mozay@opensuse.org>
- Cleaning the spec from debris.
* Sat Jun 25 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.1:
  + Use the appropriate wording and style for tooltips.
  + Allow selecting multiple files and folders.
  + Fix improper MPRIS reporting when paused.
  + Fix panic on playback state change with no window.
  + Maintain the playlist panel's width.
  + Use the display name as the song base UUID.
  + Handle nested dist folders properly.
  + Let Amberol run in the background without a window.
  + Sort files like Nautilus when adding a folder.
  + Updated translations.
* Fri May  6 2022 Dead Mozay <dead_mozay@opensuse.org>
- Initial package.
